@@ -112,7 +112,7 @@ if conchc:
                     if len(l2) < 2:
                         continue
                     try:
-                        if base64.decodestring(l2[1]) == credentials.blob:
+                        if base64.decodebytes(l2[1]) == credentials.blob:
                             return 1
                     except binascii.Error:
                         continue
@@ -158,7 +158,7 @@ class _BaseManhole(service.AsyncMultiService):
 
         super().__init__()
         if isinstance(port, int):
-            port = "tcp:%d" % port
+            port = f"tcp:{port}"
         self.port = port  # for comparison later
         self.checker = checker  # to maybe compare later
 
@@ -166,7 +166,6 @@ class _BaseManhole(service.AsyncMultiService):
             master = self.master
             namespace = {
                 'master': master,
-                'status': master.getStatus(),
                 'show': show,
             }
             return namespace
@@ -204,31 +203,15 @@ class _BaseManhole(service.AsyncMultiService):
             via = "via SSH"
         else:
             via = "via telnet"
-        log.msg("Manhole listening {} on port {}".format(via, self.port))
+        log.msg(f"Manhole listening {via} on port {self.port}")
         return super().startService()
 
 
 class TelnetManhole(_BaseManhole, ComparableMixin):
 
-    """This Manhole accepts unencrypted (telnet) connections, and requires a
-    username and password authorize access. You are encouraged to use the
-    encrypted ssh-based manhole classes instead."""
-
     compare_attrs = ("port", "username", "password")
 
     def __init__(self, port, username, password):
-        """
-        @type port: string or int
-        @param port: what port should the Manhole listen on? This is a
-        strports specification string, like 'tcp:12345' or
-        'tcp:12345:interface=127.0.0.1'. Bare integers are treated as a
-        simple tcp port.
-
-        @param username:
-        @param password: username= and password= form a pair of strings to
-                         use when authenticating the remote user.
-        """
-
         self.username = username
         self.password = password
 
@@ -240,28 +223,9 @@ class TelnetManhole(_BaseManhole, ComparableMixin):
 
 class PasswordManhole(_BaseManhole, ComparableMixin):
 
-    """This Manhole accepts encrypted (ssh) connections, and requires a
-    username and password to authorize access.
-    """
-
     compare_attrs = ("port", "username", "password", "ssh_hostkey_dir")
 
     def __init__(self, port, username, password, ssh_hostkey_dir):
-        """
-        @type port: string or int
-        @param port: what port should the Manhole listen on? This is a
-        strports specification string, like 'tcp:12345' or
-        'tcp:12345:interface=127.0.0.1'. Bare integers are treated as a
-        simple tcp port.
-
-        @param username:
-        @param password: username= and password= form a pair of strings to
-                         use when authenticating the remote user.
-        @type ssh_hostkey_dir: str
-        @param ssh_hostkey_dir: directory which contains ssh host keys for
-                                this server
-        """
-
         if not manhole_ssh:
             config.error("cryptography required for ssh mahole.")
         self.username = username
@@ -276,30 +240,9 @@ class PasswordManhole(_BaseManhole, ComparableMixin):
 
 class AuthorizedKeysManhole(_BaseManhole, ComparableMixin):
 
-    """This Manhole accepts ssh connections, and requires that the
-    prospective client have an ssh private key that matches one of the public
-    keys in our authorized_keys file. It is created with the name of a file
-    that contains the public keys that we will accept."""
-
     compare_attrs = ("port", "keyfile", "ssh_hostkey_dir")
 
     def __init__(self, port, keyfile, ssh_hostkey_dir):
-        """
-        @type port: string or int
-        @param port: what port should the Manhole listen on? This is a
-        strports specification string, like 'tcp:12345' or
-        'tcp:12345:interface=127.0.0.1'. Bare integers are treated as a
-        simple tcp port.
-
-        @param keyfile: the name of a file (relative to the buildmaster's
-                        basedir) that contains SSH public keys of authorized
-                        users, one per line. This is the exact same format
-                        as used by sshd in ~/.ssh/authorized_keys .
-        @type ssh_hostkey_dir: str
-        @param ssh_hostkey_dir: directory which contains ssh host keys for
-                                this server
-        """
-
         if not manhole_ssh:
             config.error("cryptography required for ssh mahole.")
 
@@ -339,7 +282,7 @@ class ArbitraryCheckerManhole(_BaseManhole, ComparableMixin):
 
 def show(x):
     """Display the data attributes of an object in a readable format"""
-    print("data attributes of %r" % (x,))
+    print(f"data attributes of {repr(x)}")
     names = dir(x)
     maxlen = max([0] + [len(n) for n in names])
     for k in names:
@@ -354,8 +297,8 @@ def show(x):
         elif isinstance(v, (int, type(None))):
             v = str(v)
         elif isinstance(v, (list, tuple, dict)):
-            v = "{} ({} elements)".format(v, len(v))
+            v = f"{v} ({len(v)} elements)"
         else:
             v = str(type(v))
-        print("{} : {}".format(k.ljust(maxlen), v))
+        print(f"{k.ljust(maxlen)} : {v}")
     return x
