@@ -14,6 +14,7 @@
 # Copyright Buildbot Team Members
 
 import abc
+import datetime
 import re
 
 from twisted.internet import defer
@@ -282,7 +283,10 @@ class CaptureBuildDuration(CaptureBuildTimes):
                 divisor = 60
             elif report_in == 'hours':
                 divisor = 60 * 60
-            duration = end_time - start_time
+            if end_time < start_time:
+                duration = datetime.timedelta(0)
+            else:
+                duration = end_time - start_time
             # cannot use duration.total_seconds() on Python 2.6
             duration = ((duration.microseconds + (duration.seconds +
                                                   duration.days * 24 * 3600) * 1e6) / 1e6)
