@@ -19,6 +19,7 @@ import json as jsonmodule
 import mock
 
 from twisted.internet import defer
+from twisted.logger import Logger
 from zope.interface import implementer
 
 from buildbot.interfaces import IHttpResponse
@@ -26,7 +27,6 @@ from buildbot.util import httpclientservice
 from buildbot.util import service
 from buildbot.util import toJson
 from buildbot.util import unicode2bytes
-from buildbot.util.logger import Logger
 
 log = Logger()
 
@@ -118,7 +118,11 @@ class HTTPClientService(service.SharedService):
 
     def _doRequest(self, method, ep, params=None, headers=None, data=None, json=None, files=None,
             timeout=None):
-        assert ep == "" or ep.startswith("/"), "ep should start with /: " + ep
+        if ep.startswith('http://') or ep.startswith('https://'):
+            pass
+        else:
+            assert ep == "" or ep.startswith("/"), "ep should start with /: " + ep
+
         if not self.quiet:
             log.debug("{method} {ep} {params!r} <- {data!r}",
                       method=method, ep=ep, params=params, data=data or json)
